.captcha-input {
    height: 3em;
}
.captcha-input .captcha{
    float: right;
    width: 8em;
    height: 30px;
    border: solid 1px #ccc;
    cursor: pointer;
}
.captcha-input input[type=text]{
    clear: both;
    padding: 8px;
    width: 220px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
}
body.login {
    width: 100%;
    height: 100%;
    background-repeat: no-repeat;
    background-size: cover;
    background-position: 50%;
}